@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -427,6 +427,11 @@ sub get_initialised {
 	return $META{initialised}{$caller}{$init};
 }
 
+sub get_meta {
+	my ($self, $caller) = @_;
+	return $META{$caller || ref $self};
+}
+
 1;
 
 __END__
@@ -437,7 +442,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
@@ -772,6 +777,14 @@ This returns an existing initialised object by index set in order of initialisat
 
 	Rope->get_initialised('Knot', 0);
 
+=head2 get_meta
+
+This returns the existing META definition for an object. 
+
+	Rope->get_meta('Knot');
+
+NOTE: this may change to clone the hash so that it becomes readonly, but for now it can be used to extend a meta definition if you wish.
+
 =head1 OBJECT CLASS DEFINITION
 
 	package Builder;
