@@ -98,13 +98,18 @@ sub STORE {
 		}
         } elsif (! $self->{locked}) {
                 $self->{properties}->{$key} = {
-                        value => $value,
-			initable => 1,
-			writeable => 1,
-			configurable => 1,
-			enumerable => 1,
-			index => ++$self->{keys}
-                };
+                        ((ref $value || "") eq 'HASH' && grep { defined $value->{$_} } qw/initable writeable configurable enumerable/) ? (
+				index => ++$self->{keys},
+				%{$value}
+			) : (
+				value => $value,
+				initable => 1,
+				writeable => 1,
+				configurable => 1,
+				enumerable => 1,
+				index => ++$self->{keys}
+                	)
+		};
 		push @{$self->{sort_keys}}, $key;
         } else {
 		die "Object ($self->{name}) is locked you cannot extend with new properties";
